Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Shutdowner ¶
Shutdowner is an autogenerated mock type for the Shutdowner type
func NewShutdowner ¶
func NewShutdowner(t interface {
mock.TestingT
Cleanup(func())
}) *Shutdowner
NewShutdowner creates a new instance of Shutdowner. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Shutdowner) EXPECT ¶
func (_m *Shutdowner) EXPECT() *Shutdowner_Expecter
type Shutdowner_Expecter ¶
type Shutdowner_Expecter struct {
// contains filtered or unexported fields
}
func (*Shutdowner_Expecter) Shutdown ¶
func (_e *Shutdowner_Expecter) Shutdown(ctx interface{}) *Shutdowner_Shutdown_Call
Shutdown is a helper method to define mock.On call
- ctx context.Context
type Shutdowner_Shutdown_Call ¶
Shutdowner_Shutdown_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Shutdown'
func (*Shutdowner_Shutdown_Call) Return ¶
func (_c *Shutdowner_Shutdown_Call) Return(err error) *Shutdowner_Shutdown_Call
func (*Shutdowner_Shutdown_Call) Run ¶
func (_c *Shutdowner_Shutdown_Call) Run(run func(ctx context.Context)) *Shutdowner_Shutdown_Call
func (*Shutdowner_Shutdown_Call) RunAndReturn ¶
func (_c *Shutdowner_Shutdown_Call) RunAndReturn(run func(ctx context.Context) error) *Shutdowner_Shutdown_Call
Click to show internal directories.
Click to hide internal directories.